import { isString } from "../utils/string/isString";
let currentUserId = undefined;
export const session = {
    state: {
        users: [],
        lastId: null,
    },
    init() {
        const auth = window.localStorage.getItem("auth");
        if (isString(auth)) {
            const state = JSON.parse(auth);
            // TODO: validate state
            this.state = {
                users: state.users instanceof Array ? state.users : [],
                lastId: isString(state.lastId) ? state.lastId : null,
            };
        }
    },
    getCurrent() {
        if (this.state.users.length === 0 || currentUserId == undefined) {
            return undefined;
        }
        return this.state.users.find((i) => i.subject === currentUserId);
    },
    setCurrentId(value) {
        if (isString(value) &&
            this.state.users.find((i) => i.subject === currentUserId) === null) {
            currentUserId = undefined;
        }
        else {
            currentUserId = isString(value) ? value : undefined;
        }
        this.state.lastId = isString(currentUserId) ? currentUserId : null;
        this.save();
    },
    setCurrentByAlias(value) {
        const user = this.state.users.find((u) => u?.tenant_alias === value);
        if (user != null) {
            this.setCurrentId(user.subject);
        }
    },
    getLast() {
        if (this.state.users.length === 0 || this.state.lastId == null) {
            return undefined;
        }
        return this.state.users.find((i) => i.subject === this.state.lastId);
    },
    removeUser(id) {
        this.state.users = this.state.users.filter((i) => i.subject !== id);
        this.save();
    },
    addUser(user) {
        this.state.users = this.state.users.filter((i) => i.subject !== user.subject);
        this.state.users.push(user);
        this.save();
    },
    clear() {
        this.state.users = [];
        this.save();
    },
    save() {
        if (this.state.users.length > 0) {
            window.localStorage.setItem("auth", JSON.stringify(this.state));
        }
        else {
            window.localStorage.removeItem("auth");
        }
    },
};
