import { ref, customRef } from "vue";
const debounce = (fn, delay = 0, immediate = false) => {
    let timeout;
    return (value) => {
        if (immediate && !timeout)
            fn(value);
        clearTimeout(timeout);
        if (value === "" || value == null) {
            fn(value);
            return;
        }
        timeout = setTimeout(() => {
            fn(value);
        }, delay);
    };
};
export const useDebouncedRef = (initialValue, delay = 500, immediate = false) => {
    const state = ref(initialValue);
    return customRef((track, trigger) => ({
        get() {
            track();
            return state.value;
        },
        set: debounce((value) => {
            state.value = value;
            trigger();
        }, delay, immediate),
    }));
};
